---
title: <span class="badge object-type-scalar"></span> GramPerCubicMeter
---
# <span class="badge object-type-scalar"></span> GramPerCubicMeter

Concentration: gram per cubic meter (g/m³)

## Definition

```python
# Concentration: gram per cubic meter (g/m³)
GramPerCubicMeter: typing.Literal["congm3"] = "congm3"
```
